magneticalc.Statusbar.Statusbar

# ``magneticalc`.`Statusbar`.`Statusbar``

class documentation

`class Statusbar:`

Constructor: `Statusbar(gui)`

View In Hierarchy

Statusbar class.

Method | `__init__` | Initializes statusbar.
Method | `arm` | "Arms" the statusbar before calculation.
Method | `cancel` | Cancels the ongoing calculation.
Method | `disarm` | "Disarms" the statusbar after calculation.
Method | `invalidate` | "Invalidates" the statusbar.
Method | `reload` | Reloads the statusbar.
Method | `set_progress` | Updates the progress percentage.
Method | `set_progressbar_color` | Sets the progressbar color & style.
Method | `set_text` | Updates the statusbar text.
Method | `start` | Starts the calculation.
Instance Variable | `gui` | Undocumented
Instance Variable | `layout` | Undocumented
Method | `_auto_calculation_changed` | Handles changed auto-calculation setting.
Instance Variable | `_auto_calculation_checkbox` | Undocumented
Instance Variable | `_cancel_button` | Undocumented
Instance Variable | `_canceled` | Undocumented
Instance Variable | `_cores_combobox` | Undocumented
Instance Variable | `_label` | Undocumented
Instance Variable | `_progressbar` | Undocumented
Instance Variable | `_start_button` | Undocumented
Instance Variable | `_valid` | Undocumented

def __init__(self, gui: `GUI`):

Initializes statusbar.

Parameters
gui: `GUI` | GUI

def arm(self):

"Arms" the statusbar before calculation.

def cancel(self):

Cancels the ongoing calculation.

def disarm(self, success: `bool`):

"Disarms" the statusbar after calculation.

Parameters
success: `bool` | Reflects calculation success or failure

def invalidate(self):

"Invalidates" the statusbar.

def reload(self):

Reloads the statusbar.

def set_progress(self, percentage: `int`):

Updates the progress percentage.

Parameters
percentage: `int` | Percentage

def set_progressbar_color(self, fg_color: `str`, bg_color: `str | None` = None):

Sets the progressbar color & style.

Parameters
fg_color: `str` | Foreground color
bg_color: `str | None` | Background color (optional)

def set_text(self, text: `str`):

Updates the statusbar text.

Parameters
text: `str` | Text

def start(self):

Starts the calculation.

gui =

Undocumented

layout =

Undocumented

def _auto_calculation_changed(self):

Handles changed auto-calculation setting.

_auto_calculation_checkbox =

Undocumented

_cancel_button =

Undocumented

_canceled: `bool` =

Undocumented

_cores_combobox =

Undocumented

_label =

Undocumented

_progressbar =

Undocumented

_start_button =

Undocumented

_valid: `bool` =

Undocumented